<?php

namespace App\Controller;

use Fpdf\Fpdf;

date_default_timezone_set('America/Mexico_City');

class PdfInventario extends Fpdf
{
    function Header()
    {
        $this->Image('assets/media/logos/membrete.png', 0, 0, 216);

        $this->Ln(20);
    }

    function Inventario($inventario)
    {
        $sumaGeneral = 0;
        $sumaArticulosNulos = 0;
        $this->Image('assets/media/logos/membrete.png', 0, 0, 216);
        $this->SetFont('helvetica', 'B', '13');
        $this->SetY(10);
        $this->Ln(25);
        $this->SetTextColor(0, 0, 0);

        if (count($inventario) == 0) {
            $this->Cell(180, 8, utf8_decode('SIN REGISTROS DE INVENTARIO'), 0, 0, 'C', false);
        } else {
            $categorias = array();
            $articulosNulos = array(); // Almacenar artículos con lugar de inventario nulo
            $this->SetFont('helvetica', 'B', '10');

            foreach ($inventario as $k => $f) {
                $lugarInventario = $f->getCveLugarInventario();
                if ($lugarInventario === null) {
                    $articulosNulos[] = $f; // Agregar a la lista de artículos nulos
                    $sumaArticulosNulos += $f->getStock(); // Incrementar la suma de artículos nulos
                    continue;
                }

                $categoria = $lugarInventario->getDescripcion();
                if (!isset($categorias[$categoria])) {
                    $categorias[$categoria] = array(
                        'articulos' => array(),
                        'sumaCategoria' => 0
                    );
                }
                $categorias[$categoria]['articulos'][] = $f;
                $categorias[$categoria]['sumaCategoria'] += $f->getStock();
                $sumaGeneral += $f->getStock();
            }

            $this->SetFillColor(48, 149, 124);
            $this->SetFont('helvetica', 'B', '10');

            foreach ($categorias as $categoria => $data) {
                $articulos = $data['articulos'];

                $this->SetFont('helvetica', 'B', '10');
                $this->Cell(19, 10, utf8_decode(''), 0, 0, 'R');
                $this->SetFillColor(255, 255, 255);
                $this->SetTextColor(0, 0, 0);
                $this->Cell(150, 8, utf8_decode('LUGAR EN LOS QUE SE ENCUANTRAN LOS ARTICULOS: ' . $categoria), 1, 0, 'C', true);
                $this->Ln(8);
                $this->SetFont('helvetica', '', '8');
                $this->SetTextColor(255, 255, 255);
                $this->SetFillColor(48, 149, 124);
                $this->SetFont('helvetica', 'B', '8');
                $this->Cell(19, 8, utf8_decode(''), 0, 0, 'R');
                $this->Cell(15, 8, utf8_decode('#'), 1, 0, 'C', true);
                $this->Cell(100, 8, utf8_decode('ARTÍCULO'), 1, 0, 'C', true);
                $this->Cell(35, 8, utf8_decode('CANTIDAD'), 1, 0, 'C', true);
                $this->Ln(8);
                $this->SetFont('helvetica', '', '8');

                foreach ($articulos as $k => $f) {
                    $this->SetTextColor(0, 0, 0);
                    $this->Cell(19, 8, utf8_decode(''), 0, 0, 'R');
                    $this->Cell(15, 8, utf8_decode($k + 1), 1, 0, 'C');
                    $this->Cell(100, 8, utf8_decode($f->getCveArticulo()->getNomArticulo()), 1, 0, 'J');
                    $this->Cell(35, 8, utf8_decode($f->getStock()), 1, 0, 'C');
                    $this->Ln();
                }

                $this->Ln(5);
            }
            $this->Ln(8);
            $this->SetFont('helvetica', 'B', '8');
            foreach ($categorias as $categoria => $data) {
                $this->SetX(29);
                $sumaCategoria = $data['sumaCategoria'];
                $this->SetTextColor(0, 0, 0);
                $this->SetFillColor(255, 255, 255);
                $this->Cell(115, 8, utf8_decode('TOTAL DE ' . $categoria . ':'), 1, 0, 'L', true);
                $this->SetTextColor(0, 0, 0);
                $this->Cell(35, 8, ' ' . number_format($sumaCategoria) . ".", 1, 0, 'C', false);
                $this->Ln(8);
            }

            $this->Ln(10);
            $this->SetX(29);
            $this->SetFont('helvetica', 'B', '8');
            $this->SetTextColor(255, 255, 255);
            $this->SetFillColor(48, 149, 124);
            $this->Cell(115, 8, utf8_decode('TOTAL DE ARTÍCULOS:'), 1, 0, 'L', true);
            $this->SetTextColor(0, 0, 0);
            $this->Cell(35, 8, ' ' . number_format($sumaGeneral) . ".", 1, 0, 'C', false);
            $this->Ln(20);
            $this->Ln();

            $sumaArtNul = 0;
            if (count($articulosNulos) > 0) {
                $this->SetFont('helvetica', 'B', '10');
                $this->Cell(19, 10, utf8_decode(''), 0, 0, 'R');
                $this->SetFillColor(255, 255, 255);
                $this->SetTextColor(0, 0, 0);
                $this->Cell(150, 8, utf8_decode('ARTÍCULOS SIN ASIGNACIÓN DE LUGAR'), 1, 0, 'C', true);
                $this->Ln(8);
                $this->SetFont('helvetica', 'B', '8');
                $this->SetTextColor(255, 255, 255);
                $this->SetFillColor(48, 149, 124);
                $this->Cell(19, 8, utf8_decode(''), 0, 0, 'R');
                $this->Cell(15, 8, utf8_decode('#'), 1, 0, 'C', true);
                $this->Cell(100, 8, utf8_decode('ARTÍCULO'), 1, 0, 'C', true);
                $this->Cell(35, 8, utf8_decode('CANTIDAD'), 1, 0, 'C', true);
                $this->Ln(8);
                $this->SetFont('helvetica', '', '8');

                foreach ($articulosNulos as $k => $f) {
                    $this->SetTextColor(0, 0, 0);
                    $this->Cell(19, 8, utf8_decode(''), 0, 0, 'R');
                    $this->Cell(15, 8, utf8_decode($k + 1), 1, 0, 'C');
                    $this->Cell(100, 8, utf8_decode($f->getCveArticulo()->getNomArticulo()), 1, 0, 'J');
                    $this->Cell(35, 8, utf8_decode($f->getStock()), 1, 0, 'C');

                    $sumaArtNul += $f->getStock();
                    $this->Ln();
                }

            }

            $this->SetX(29);
            $this->SetFont('helvetica', 'B', '8');
            $this->SetTextColor(255, 255, 255);
            $this->SetFillColor(48, 149, 124);
            $this->Cell(115, 8, utf8_decode('TOTAL DE ARTÍCULOS SIN ASIGNACIÓN DE LUGAR:'), 1, 0, 'L', true);
            $this->SetTextColor(0, 0, 0);
            $this->Cell(35, 8, ' ' . number_format($sumaArtNul) . ".", 1, 0, 'C', false);
            $this->Ln(20);
        }
    }

    function MovimientosInventario($articulos)
    {

        $this->Image('assets/media/logos/membrete.png', 0, 0, 216);
        $this->SetFont('helvetica', 'B', 11);
        $this->SetY(10);
        $this->Cell(188, 15, utf8_decode('MOVIMIENTOS INVENTARIO'), 0, 0, 'C');
        $this->Ln(25);

        if (count($articulos) == 0) {
            $this->Ln();
            $this->SetFillColor(48, 149, 124);
            $this->SetTextColor(255, 255, 255);
            $this->Cell(195, 8, utf8_decode('SIN REGISTRO DE MOVIMIENTOS  --°_°--'), 0, 0, 'C', true);
            $this->Ln(10);
        } else {
            $this->SetFillColor(48, 149, 124);
            $this->SetTextColor(255, 255, 255);
            $this->SetFont('helvetica', 'B', 10);
            $this->Cell(15, 7, utf8_decode('#'), 1, 0, 'C', true);
            $this->Cell(25, 7, utf8_decode('Articulo'), 1, 0, 'C', true);
            $this->Cell(25, 7, utf8_decode('Cantidad'), 1, 0, 'C', true);
            $this->Cell(30, 7, utf8_decode('Tipo'), 1, 0, 'C', true);
            $this->Cell(65, 7, utf8_decode('Observaciones'), 1, 0, 'C', true);
            $this->Cell(35, 7, utf8_decode('Fecha Movimiento'), 1, 0, 'C', true);
            $this->Ln();
            $this->SetTextColor(0, 0, 0);

            foreach ($articulos as $k => $m) {

                $this->SetFont('helvetica', '', 8);
                $this->Cell(15, 7, utf8_decode($k + 1), 1, 0, 'C', false);
                $this->Cell(25, 7, utf8_decode($m->getCveInventario()->getCveArticulo()->getNomArticulo()), 1, 0, 'C');
                $this->Cell(25, 7, utf8_decode($m->getCantidad()), 1, 0, 'C');
                if ($m->isTipoMovimiento() == 1) {
                    $this->Cell(30, 7, utf8_decode('Agrego'), 1, 0, 'C');
                } else {
                    $this->Cell(30, 7, utf8_decode('Quito'), 1, 0, 'C');
                }
                $this->Cell(65, 7, utf8_decode($m->getObservaciones()), 1, 0, 'C');
                $this->Cell(35, 7, utf8_decode($m->getFecMovimiento()->format('Y/m/d')), 1, 0, 'C');
                $this->Ln();
            }
        }
    }
}

