<?php

namespace App\Controller;

use App\Entity\Agenda;
use App\Entity\Area;
use App\Entity\CategoriasMenu;
use App\Entity\Empleados;
use App\Entity\Evento;
use App\Entity\Menus;
use App\Entity\Mesas;
use App\Entity\ModoPagos;
use App\Entity\Servicios;
use App\Entity\ServiciosCuenta;
use App\Entity\ServiciosMenu;
use App\Entity\TiposServicio;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\Persistence\ManagerRegistry;
use MongoDB\BSON\Javascript;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\json_encode;
use Symfony\Component\HttpFoundation\JsonResponse;

date_default_timezone_set('America/Mexico_City');

class ServiciosController extends AbstractController
{
    #[Route('/registrarServicio', name: 'registrar_servicio')]
    public function registrarServicio(Request $request, ManagerRegistry $doctrine): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $ideMesa = $request->get('cveMesa');
                $ideMenu = $request->get('cveMenu');
                $ideEmpleado = $request->get('cveEmpleado');

                $mesa = $em->getRepository(Mesas::class)->findOneBy(['ideMes' => $ideMesa]);
                $menu = $em->getRepository(Menus::class)->findOneBy(['ideMen' => $ideMenu]);
                $empleado = $em->getRepository(Empleados::class)->findOneBy(
                    ['ideEmp' => $ideEmpleado, 'estatus' => 1]);
                $tipoServicio = $em->getRepository(TiposServicio::class)
                    ->findOneBy(['ideTipSer' => '1']); // PARA AQUÍ

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['cveMes' => $mesa, 'estatus' => 1]
                    );
                if ($servicio) {
                    $session->getFlashBag()->add('mensaje', 'Ya EXISTE un servicio ACTIVO.');
                } else {
                    $servicio = new Servicios();
                    $servicio->setCveMes($mesa);
                    $servicio->setCveEmp($empleado);
                    $servicio->setEstatus(1);
                    $servicio->setCveTipSer($tipoServicio);
                    $servicio->setFecMov(new \DateTime(date('Y-m-d')));
                    $servicio->setHorMov(new \DateTime(date('H:i:s')));
                    $servicio->setHorCierre(null);
                    $servicio->setCancelarServicio(0);

                    $em->persist($servicio);
                    $em->flush();

                    $servicioMenu = new ServiciosMenu();
                    $servicioMenu->setCveSer($servicio);
                    $servicioMenu->setCveMen($menu);
                    $servicioMenu->setPrecio($menu->getPrecio());
                    $servicioMenu->setDescuento(0);
                    $servicioMenu->setSubtotal($menu->getPrecio());

                    $em->persist($servicioMenu);
                    $em->flush();

                    $session->getFlashBag()->add('mensaje', 'Se ha REGISTRADO el Servicio.');

                }

                $serviciosMenu = $em->getRepository(ServiciosMenu::class)
                    ->findBy(['cveSer' => $servicio]);

                return $this->render('Servicios/respuesta-alta-servicio.html.twig',
                    ['servicio' => $servicio, 'serviciosMenu' => $serviciosMenu]
                );


            } else { // ES GET
                $em = $doctrine->getManager();

                $ideServicio = $request->get('ideServicio');

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['ideSer' => $ideServicio, 'estatus' => 1]
                    );

                $serviciosMenu = $em->getRepository(ServiciosMenu::class)
                    ->findBy(['cveSer' => $servicio]);

                return $this->render('Servicios/respuesta-alta-servicio.html.twig',
                    ['servicio' => $servicio, 'serviciosMenu' => $serviciosMenu]
                );
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }

    #[Route('/agregarOrden', name: 'agregar_orden')]
    public function agregarOrden(Request $request, ManagerRegistry $doctrine): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $ideServicio = $request->get('ideServicio');
                $ideMenu = $request->get('ideMenu');

                $menu = $em->getRepository(Menus::class)->findOneBy(['ideMen' => $ideMenu]);

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['ideSer' => $ideServicio, 'estatus' => 1]
                    );

                $servicioMenu = new ServiciosMenu();
                $servicioMenu->setCveSer($servicio);
                $servicioMenu->setCveMen($menu);
                $servicioMenu->setPrecio($menu->getPrecio());
                $servicioMenu->setDescuento(0);
                $servicioMenu->setSubtotal($menu->getPrecio());

                $em->persist($servicioMenu);
                $em->flush();

                $serviciosMenu = $em->getRepository(ServiciosMenu::class)
                    ->findBy(['cveSer' => $servicio]);


                return $this->render('Servicios/respuesta-alta-servicio.html.twig',
                    ['servicio' => $servicio, 'serviciosMenu' => $serviciosMenu]
                );
            } else { // ES GET
                return $this->redirect($this->generateUrl('login'));
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }

    #[Route('/quitarOrden', name: 'quitar_orden')]
    public function quitarOrden(Request $request, ManagerRegistry $doctrine): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $ideServicio = $request->get('ideServicio');
                $ideServicioMenu = $request->get('ideServicioMenu');

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['ideSer' => $ideServicio, 'estatus' => 1]
                    );

                $servicioMenu = $em->getRepository(ServiciosMenu::class)
                    ->findOneBy(['ideSerMen' => $ideServicioMenu, 'cveSer' => $servicio]);

                $em->remove($servicioMenu);
                $em->flush();

                $serviciosMenu = $em->getRepository(ServiciosMenu::class)
                    ->findBy(['cveSer' => $servicio]);


                return $this->render('Servicios/respuesta-alta-servicio.html.twig',
                    ['servicio' => $servicio, 'serviciosMenu' => $serviciosMenu]
                );
            } else { // ES GET
                return $this->redirect($this->generateUrl('login'));
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }

    #[Route('/cerrarCuenta', name: 'cerrar_cuenta')]
    public function cerrarCuenta(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $ideServicio = $request->get('ideServicio');

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['ideSer' => $ideServicio, 'estatus' => 1]
                    );

                $serviciosMenu = $em->getRepository(ServiciosMenu::class)
                    ->findBy(['cveSer' => $servicio]);

                $formasPago = $em->getRepository(ModoPagos::class)->findAll();

                $dql = "select " .
                    "IDENTITY(sm.cveSer) cveSer, IDENTITY(sm.cveMen) cveMen, m.nomMen, sm.precio, count(sm) total, SUM(sm.descuento) descuento,SUM(sm.subtotal) subtotal " .
                    "from App\Entity\ServiciosMenu sm, " .
                    "App\Entity\Menus m " .
                    "where " .
                    "m.ideMen = sm.cveMen " .
                    "and " .
                    "sm.cveSer = $ideServicio " .
                    "group by sm.cveMen";
                $query = $entityManager->createQuery($dql);
                $cuenta = $query->getResult();


                $sumaSubtotal = 0;

                foreach ($serviciosMenu as $sm) {
                    $sumaSubtotal += $sm->getSubtotal();
                }

                $servicioCuenta = new ServiciosCuenta();
                $servicioCuenta->setCveSer($servicio);
                $servicioCuenta->setSubtotal($sumaSubtotal);
                $servicioCuenta->setDescuento(0);
                $servicioCuenta->setTotal($sumaSubtotal);
                $em->persist($servicioCuenta);
                $em->flush();

                $servicio->setEstatus(0);
                $servicio->setHorCierre(new \DateTime(date('H:i:s')));
                $em->persist($servicio);
                $em->flush();

                return $this->render('Servicios/respuesta-cerrar-servicio.html.twig',
                    [
                        'servicio' => $servicio, 'serviciosMenu' => $serviciosMenu,
                        'cuenta' => $cuenta, 'formasPago' => $formasPago
                    ]
                );
            } else { // ES GET
                return $this->redirect($this->generateUrl('login'));
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }

    #[Route('/imprimirNota', name: 'imprimir_nota')]
    public function imprimirNota(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'GET') {
                $em = $doctrine->getManager();

                $ideServicio = $request->get('ideServicio');

                $servicio = $em->getRepository(Servicios::class)
                    ->findOneBy(
                        ['ideSer' => $ideServicio]
                    );

                $dql = "select " .
                    "IDENTITY(sm.cveSer) cveSer, IDENTITY(sm.cveMen) cveMen, m.nomMen, sm.precio, count(sm) total, SUM(sm.descuento) descuento,SUM(sm.subtotal) subtotal " .
                    "from App\Entity\ServiciosMenu sm, " .
                    "App\Entity\Menus m " .
                    "where " .
                    "m.ideMen = sm.cveMen " .
                    "and " .
                    "sm.cveSer = $ideServicio " .
                    "group by sm.cveMen";
                $query = $entityManager->createQuery($dql);
                $cuenta = $query->getResult();


                $pdf = new PdfTicket('P', 'mm', array(48, 200));
                $pdf->SetFont('Helvetica', '', 8);
                $pdf->AddPage();
                $pdf->SetLeftMargin(0);
                $pdf->SetRightMargin(4);
                $pdf->generarNota($servicio, $cuenta);

                return new Response(
                    $pdf->Output('nota.pdf', 'I'),
                    200,
                    array('Content-Type' => 'application/pdf')
                );

            } else { // ES POST
                return $this->redirect($this->generateUrl('login'));
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }

    #[Route('/listarMesasActivas', name: 'listar_mesas_activas')]
    public function listarMesasActivas(Request $request, ManagerRegistry $doctrine): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $ideMesaActiva = $request->get('ideMesaActiva');

                $servicios = $em->getRepository(Servicios::class)
                    ->findBy(['estatus' => 1], ['cveMes' => 'ASC']);

                return $this->render('Servicios/lista-mesas-activas.html.twig',
                    [
                        'servicios' => $servicios, 'ideMesaActiva' => $ideMesaActiva
                    ]
                );
            } else { // ES GET
                $em = $doctrine->getManager();

                $ideMesaActiva = null;

                $servicios = $em->getRepository(Servicios::class)
                    ->findBy(['estatus' => 1], ['cveMes' => 'ASC']);

                return $this->render('Servicios/lista-mesas-activas.html.twig',
                    [
                        'servicios' => $servicios, 'ideMesaActiva' => $ideMesaActiva
                    ]
                );
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }

    }

    #[Route('/listarMesasDisponibles', name: 'listar_mesas_disponibles')]
    public function listarMesasDisponibles(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {

                $dql = "SELECT m FROM App\Entity\Mesas m WHERE  m.ideMes NOT  IN( SELECT IDENTITY(s.cveMes) FROM App\Entity\Servicios s WHERE s.estatus = 1)";
                $query = $entityManager->createQuery($dql);
                $mesasDisponibles = $query->getResult();

                return $this->render('Servicios/lista-mesas-disponibles.html.twig',
                    [
                        'mesasDisponibles' => $mesasDisponibles
                    ]
                );
            } else { // ES GET
                return $this->redirect($this->generateUrl('login'));
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }

    }


    #[Route('/agenda', name: 'agregar_res_agenda')]
    public function agenda(Request $request, ManagerRegistry $doctrine): Response
    {

        if ($request->getMethod() == 'POST') {
            $em = $doctrine->getManager();
            $nombrePersona = $request->get('nombre');
            $apellidoPat = $request->get('apellidoPat');
            $apellidoMat = $request->get('apellidoMat');
            $telefono = $request->get('telefono');
            $email = $request->get('email');
            $tipoReservacion = $request->get('tipoReservacion');
            $tipoEvento = $request->get('evento');
            $TipoMesa = $request->get('mesa');
            $puertaCerrada = $request->get('puertaCerrada');
            $tipoArea = $request->get('area');
            $fechaReserva = $request->get('fechCom');
            $horaReserva = $request->get('horCom');
            $fechaTerminoReserva = $request->get('fechaTer');
            $horaTerminoReserva = $request->get('horaTer');

            $evento = $em->getRepository(Evento::class)->findOneBy(['ideEvento' => $tipoEvento]);
            $mesa = $em->getRepository(Mesas::class)->findOneBy(['ideMes' => $TipoMesa]);
            $area = $em->getRepository(Area::class)->findOneBy(['ideArea' => $tipoArea]);

            $reservacion = new Agenda();
            $reservacion->setNombre($nombrePersona);
            $reservacion->setApellidoPat($apellidoPat);
            $reservacion->setApellidoMat($apellidoMat);
            $reservacion->setTelefono($telefono);
            $reservacion->setEmail($email);
            $reservacion->setTipoReservacion($tipoReservacion);

            $reservacion->setCveEvento($evento);


            if ($TipoMesa == " ") {
                $reservacion->setCveMesa(null);
            } else {
                $reservacion->setCveMesa($mesa);
            }

            if ($puertaCerrada == " ") {
                $reservacion->setPuertaCerrada('null');
            } else {
                $reservacion->setPuertaCerrada($puertaCerrada);
            }

            if ($tipoArea == " ") {
                $reservacion->setCveArea(null);
            } else {
                $reservacion->setCveArea($area);
            }
            $reservacion->setReserva(new \DateTime($fechaReserva));
            $reservacion->setHoraReserva(new \DateTime($horaReserva));
            $reservacion->setFecTerminoReserva(new \DateTime($fechaTerminoReserva));
            $reservacion->setHoraTerminoReserva(new \DateTime($horaTerminoReserva));
            $reservacion->setFecMov(new \DateTime(date('Y-m-d')));
            $reservacion->setHorMov(new \DateTime(date('H:i:s')));
            $em->persist($reservacion);
            $em->flush();
            return $this->redirect($this->generateUrl('home_page'));

        } else { // ES GET
            $em = $doctrine->getManager();

            $agenda = $em->getRepository(Agenda::class);
            $mesa = $em->getRepository(Mesas::class)->findAll();
            $area = $em->getRepository(Area::class)->findAll();
            $tipoEvento = $em->getRepository(Evento::class)->findAll();

            return $this->render('Servicios/agenda.html.twig',
                [
                    'mesa' => $mesa,
                    'agenda' => $agenda,
                    'area' => $area,
                    'evento' => $tipoEvento
                ]
            );

        }
        return $this->redirect($this->generateUrl('login'));
    }


    #[Route('/contenedorAgenda', name: 'contenedor-agenda')]
    public function contenedorAgenda(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();
            } else { // ES GET
                $em = $doctrine->getManager();
                //$fechaSemana = $request->get('fecha');
                $Mes = $request->get('Mes');
                $primer_Dia = $Mes . "-01";
                $Ultimo_dia = new \DateTime($primer_Dia);
                $Ultimo_dia->modify('Last day of this month');


                $dql = "SELECT a.ideAgenda ideAgenda, a.fecReserva fecReserva, e.descripcion DESCRIPCION, a.horaReserva HORA, a.fecTerminoReserva TERMINO, a.horaTerminoReserva HTERMINO "
                    . "FROM App\Entity\Agenda a, App\Entity\Evento e "
                    . "WHERE a.fecReserva "
                    . "BETWEEN "
                    . "' " . $primer_Dia . "' "
                    . "AND "
                    . "' " . $Ultimo_dia->format('Y/m/d') . "' "
                    . "AND "
                    . "a.cveEvento = e.ideEvento ";
                $query = $entityManager->createQuery($dql);
                $agenda = $query->getResult();

                $datos = [];
                foreach ($agenda as $d) {
                    $datos[] = [
                        $d['ideAgenda'],
                        $d['fecReserva']->format('Y-m-d'),
                        $d['DESCRIPCION'],
                        $d['HORA']->format('H:i:s'),
                        $d['TERMINO']->format('Y-m-d'),
                        $d['HTERMINO']->format('H:i:s'),

                    ];
                }


                return new JsonResponse($datos);

                /*return $this->render('Servicios\contenedor-agenda.html.twig', [
                    'agenda' => $agenda]);
                */
            }

        }


        return $this->redirect($this->generateUrl('login'));
    }


    #[Route('/pdfReserva', name: 'pdfReserva')]
    public function pdfReserva(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();
            } else {
                $em = $doctrine->getManager();

                $eventId = $request->query->get('id'); // Obtener el ID del evento desde la URL
                $eventDate = $request->query->get('fecha');


                $Mes = $request->get('Mes');
                $primer_Dia = $Mes . "-01";
                $Ultimo_dia = new \DateTime($primer_Dia);
                $Ultimo_dia->modify('Last day of this month');


                $dql = "SELECT a.ideAgenda ideAgenda, a.fecReserva fecReserva, e.descripcion DESCRIPCION, a.horaReserva HORA, a.fecTerminoReserva TERMINO, a.horaTerminoReserva HTERMINO "
                    . "FROM App\Entity\Agenda a, App\Entity\Evento e "
                    . "WHERE a.fecReserva "
                    . "BETWEEN "
                    . "' " . $primer_Dia . "' "
                    . "AND "
                    . "' " . $Ultimo_dia->format('Y/m/d') . "' "
                    . "AND "
                    . "a.cveEvento = e.ideEvento ";
                $query = $entityManager->createQuery($dql);
                $agenda = $query->getResult();


                $eventId = $request->get('ideAgenda');
                $evento = $em->getRepository(Agenda::class)
                    ->findBy(['ideAgenda' => $eventId]);

                $pdf = new PdfReservacion('P', 'mm', 'letter');
                $pdf->SetFont('Helvetica', '', 8);
                $pdf->AddPage();
                $pdf->SetLeftMargin(10);
                $pdf->SetRightMargin(10);
                $pdf->pdfReservas($evento);
                $filename = 'Reserva' . date('Y-m-d') . '.pdf';
                $pdf->Output($filename, 'I');

            }
        }

    }

    #[Route('/descripcionSer', name: 'new-ser')]
    public function descripcionSer(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();

                $nombreMen = $request->get('nomSerMen');
                $descripcionMen = $request->get('desSerMen');
                $precio = $request->get('preSerMen');
                $cveCatMen = $request->get('tipoSerMen');

                $servicio = $em->getRepository(CategoriasMenu::class)->findOneBy(['ideCatMen' => $cveCatMen]);

                $menus = new Menus();
                $menus->setNomMen($nombreMen);
                $menus->setDesMen($descripcionMen);
                $menus->setPrecio($precio);
                $menus->setCveCatMen($servicio);
                $menus->setImgMen(null);
                $em->persist($menus);
                $em->flush();

                return $this->render('Servicios/contenedor-nuevos-servicios.html.twig', [
                    'buffet' => $servicio
                ]);
            } else { // ES GET
                $em = $doctrine->getManager();
                $buffet = $em->getRepository(CategoriasMenu::class)->findAll();
                return $this->render('Servicios/contenedor-nuevos-servicios.html.twig', [
                    'buffet' => $buffet
                ]);
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }

    }


    #[Route('/fromularioEvento', name: 'formularioEvento')]
    public function fromularioEvento(Request $request, ManagerRegistry $doctrine): Response
    {
        $session = $request->getSession();
        if ($session->has('ideUsuario')) {
            if ($request->getMethod() == 'POST') {
                $em = $doctrine->getManager();
                $nombreEvento = $request->get('evento');

                $evento = new Evento();
                $evento->setDescripcion($nombreEvento);
                $em->persist($evento);
                $em->flush();
                return $this->redirect($this->generateUrl('home_page'));
            } else { // ES GET
                $em = $doctrine->getManager();
                return $this->render('Reportes/contenedor-nuevo-evento.html.twig');
            }
        } else {
            return $this->redirect($this->generateUrl('login'));
        }
    }


    /*
        #[Route('/imprimirCorteTMes', name: 'imprimir_CorteT_Mes')]
        public function imprimirCorteTMes(Request $request, ManagerRegistry $doctrine, EntityManagerInterface $entityManager): Response
        {
            $session = $request->getSession();
            if ($session->has('ideUsuario')) {
                if ($request->getMethod() == 'POST') {
                    return $this->redirect($this->generateUrl('login'));
                } else { // ES GET
                    $em = $doctrine->getManager();

                    $fechaTicket = $request->get('cortePorMesPC');

                    $primerDia = $fechaTicket . "-01";
                    $fechaFin = new \DateTime($primerDia);
                    $fechaFin->modify('Last day of this month');

                    /* SELECT
     COUNT(i.cve_ser_cue) serviciosCuenta,
     SUM(i.total) AS SER,
     i.fec_mov AS FECHA,
     SUM(i.propina) AS propina
     FROM ingresos i
     WHERE i.fec_mov
     BETWEEN
     '2023-05-01'
     AND
     '2023-05-31'
     AND
     i.cve_mod_pag_propina IN( SELECT m.ide_mod_pag FROM modo_pagos m WHERE i.cve_mod_pag_propina IN(2) )
     GROUP BY i.fec_mov;


                    $dql = "SELECT "
                        . "COUNT(i.cveSerCue) SERVICIOS, "
                        . "SUM(i.total) TOTAL_SER, "
                        . "i.fecMov, "
                        . "SUM(i.propina) PROPINA "
                        . "FROM App\Entity\Ingresos i "
                        . "WHERE i.fecMov "
                        . "BETWEEN "
                        . "' " . $primerDia . "' "
                        . "AND "
                        . "' " . $fechaFin->format('Y-m-d') . "' "
                        . "AND "
                        . "i.cveModPagPropina IN (SELECT m.ideModPag FROM App\Entity\ModoPagos m WHERE i.cveModPagPropina IN(1)) "
                        . "GROUP BY i.fecMov ";

                    $query = $entityManager->createQuery($dql);
                    $corteTicketMes = $query->getResult();


                    $dql2 = "SELECT "
                        . "COUNT(i.cveSerCue) SERVICIOS, "
                        . "SUM(i.total) TOTAL_SER, "
                        . "i.fecMov, "
                        . "SUM(i.propina) PROPINA "
                        . "FROM App\Entity\Ingresos i "
                        . "WHERE i.fecMov "
                        . "BETWEEN "
                        . "' " . $primerDia . "' "
                        . "AND "
                        . "' " . $fechaFin->format('Y-m-d') . "' "
                        . "AND "
                        . "i.cveModPagPropina IN (SELECT m.ideModPag FROM App\Entity\ModoPagos m WHERE i.cveModPagPropina IN(2)) "
                        . "GROUP BY i.fecMov ";

                    $query = $entityManager->createQuery($dql2);
                    $corteTicketMes2 = $query->getResult();

                    $pdf = new PdfNotas('P', 'mm', 'letter');
                    $pdf->SetFont('Helvetica', '', 8);
                    $pdf->AddPage();
                    $pdf->SetLeftMargin(10);
                    $pdf->SetRightMargin(10);
                    $pdf->buffetPorMes($corteTicketMes, $corteTicketMes2, $fechaTicket);


                    return new Response(
                        $pdf->Output('BuffetDelMes_' . $primerDia . '.pdf', 'I'),
                        200,
                        array('Content-Type' => 'application/pdf')
                    );
                }
            } else {
                return $this->redirect($this->generateUrl('login'));
            }
        }
    */
}